import { csv } from 'd3';

// URL of the dataset
const csvUrl =
  'https://raw.githubusercontent.com/kowshiksamudrala08/datasets/main/data_science_salaries.csv';

// Function to fetch and prepare the data
export const fetchData = async () => {
  // Load the CSV data
  const data = await csv(csvUrl);

  // Filter data for years 2020 to 2024
  const filteredData = data.filter(
    (d) => d.work_year >= 2020 && d.work_year <= 2024,
  );

  // Group data by year, job title, experience level, and location, and calculate total salary
  const aggregatedData = d3.rollup(
    filteredData,
    (v) => d3.sum(v, (d) => d.salary),
    (d) => d.work_year,
    (d) => d.job_title,
    (d) => d.experience_level,
    (d) => d.location,
  );

  return aggregatedData;
};

// Function to render pie chart
export const renderPieChart = (year, data) => {
  // Define SVG dimensions
  const width = 500;
  const height = 500;
  const radius = Math.min(width, height) / 2;

  // Select container
  const container = d3
    .select('#chart-container')
    .append('div')
    .attr('class', 'chart')
    .style('width', width + 'px')
    .style('height', height + 'px');

  // Create SVG element
  const svg = container
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr(
      'transform',
      'translate(' + width / 2 + ',' + height / 2 + ')',
    );

  // Define pie chart parameters
  const pie = d3
    .pie()
    .value((d) => d[1])
    .sort(null);

  const arc = d3.arc().innerRadius(0).outerRadius(radius);

  const color = d3.scaleOrdinal(d3.schemeCategory10);

  // Generate pie chart data
  const pieData = pie(data.get(year).entries());

  // Append arcs to SVG
  const arcs = svg
    .selectAll('arc')
    .data(pieData)
    .enter()
    .append('g')
    .attr('class', 'arc');

  // Append path for each arc
  arcs
    .append('path')
    .attr('d', arc)
    .attr('fill', (d) => color(d.data[0]));

  // Append text labels
  arcs
    .append('text')
    .attr(
      'transform',
      (d) => 'translate(' + arc.centroid(d) + ')',
    )
    .attr('dy', '0.35em')
    .text((d) => d.data[0]);
};
